==> istio-model-v1alpha3-6.0.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/L4MatchAttributesFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface L4MatchAttributesFluent<A extends L4MatchAttributesFluent<A>> extends Fluent<A>{
  public A addToDestinationSubnets(Integer index,String item);
  public A setToDestinationSubnets(Integer index,String item);
  public A addToDestinationSubnets(java.lang.String... items);
  public A addAllToDestinationSubnets(Collection<String> items);
  public A removeFromDestinationSubnets(java.lang.String... items);
  public A removeAllFromDestinationSubnets(Collection<String> items);
  public List<String> getDestinationSubnets();
  public String getDestinationSubnet(Integer index);
  public String getFirstDestinationSubnet();
  public String getLastDestinationSubnet();
  public String getMatchingDestinationSubnet(Predicate<String> predicate);
  public Boolean hasMatchingDestinationSubnet(Predicate<String> predicate);
  public A withDestinationSubnets(List<String> destinationSubnets);
  public A withDestinationSubnets(java.lang.String... destinationSubnets);
  public Boolean hasDestinationSubnets();
  public A addToGateways(Integer index,String item);
  public A setToGateways(Integer index,String item);
  public A addToGateways(java.lang.String... items);
  public A addAllToGateways(Collection<String> items);
  public A removeFromGateways(java.lang.String... items);
  public A removeAllFromGateways(Collection<String> items);
  public List<String> getGateways();
  public String getGateway(Integer index);
  public String getFirstGateway();
  public String getLastGateway();
  public String getMatchingGateway(Predicate<String> predicate);
  public Boolean hasMatchingGateway(Predicate<String> predicate);
  public A withGateways(List<String> gateways);
  public A withGateways(java.lang.String... gateways);
  public Boolean hasGateways();
  public Integer getPort();
  public A withPort(Integer port);
  public Boolean hasPort();
  public A addToSourceLabels(String key,String value);
  public A addToSourceLabels(Map<String,String> map);
  public A removeFromSourceLabels(String key);
  public A removeFromSourceLabels(Map<String,String> map);
  public Map<String,String> getSourceLabels();
  public <K,V>A withSourceLabels(Map<String,String> sourceLabels);
  public Boolean hasSourceLabels();
  public String getSourceNamespace();
  public A withSourceNamespace(String sourceNamespace);
  public Boolean hasSourceNamespace();
  public String getSourceSubnet();
  public A withSourceSubnet(String sourceSubnet);
  public Boolean hasSourceSubnet();
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/L4MatchAttributesFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface L4MatchAttributesFluent<A extends L4MatchAttributesFluent<A>> extends Fluent<A>{
  public A addToDestinationSubnets(int index,String item);
  public A setToDestinationSubnets(int index,String item);
  public A addToDestinationSubnets(java.lang.String... items);
  public A addAllToDestinationSubnets(Collection<String> items);
  public A removeFromDestinationSubnets(java.lang.String... items);
  public A removeAllFromDestinationSubnets(Collection<String> items);
  public List<String> getDestinationSubnets();
  public String getDestinationSubnet(int index);
  public String getFirstDestinationSubnet();
  public String getLastDestinationSubnet();
  public String getMatchingDestinationSubnet(Predicate<String> predicate);
  public Boolean hasMatchingDestinationSubnet(Predicate<String> predicate);
  public A withDestinationSubnets(List<String> destinationSubnets);
  public A withDestinationSubnets(java.lang.String... destinationSubnets);
  public Boolean hasDestinationSubnets();
  public A addToGateways(int index,String item);
  public A setToGateways(int index,String item);
  public A addToGateways(java.lang.String... items);
  public A addAllToGateways(Collection<String> items);
  public A removeFromGateways(java.lang.String... items);
  public A removeAllFromGateways(Collection<String> items);
  public List<String> getGateways();
  public String getGateway(int index);
  public String getFirstGateway();
  public String getLastGateway();
  public String getMatchingGateway(Predicate<String> predicate);
  public Boolean hasMatchingGateway(Predicate<String> predicate);
  public A withGateways(List<String> gateways);
  public A withGateways(java.lang.String... gateways);
  public Boolean hasGateways();
  public Integer getPort();
  public A withPort(Integer port);
  public Boolean hasPort();
  public A addToSourceLabels(String key,String value);
  public A addToSourceLabels(Map<String,String> map);
  public A removeFromSourceLabels(String key);
  public A removeFromSourceLabels(Map<String,String> map);
  public Map<String,String> getSourceLabels();
  public <K,V>A withSourceLabels(Map<String,String> sourceLabels);
  public Boolean hasSourceLabels();
  public String getSourceNamespace();
  public A withSourceNamespace(String sourceNamespace);
  public Boolean hasSourceNamespace();
  public String getSourceSubnet();
  public A withSourceSubnet(String sourceSubnet);
  public Boolean hasSourceSubnet();
  
}
